---
title: LED Ring tab
page_id: led_ring_tab
sort_order: 10
---

The **LED Ring** tab lets you control the **LED-ring deck** attached to your Crazyflie.
Choose from a variety of built-in patterns or customize each of the 12 individual LEDs to create your own lighting setup.

![cfclient color LED](/docs/images/ledring_tab.png)

The tab is divided into 3 sections:
1.  Lighthing Effects
2.  Intensity
3.  Individual LEDs


### 1. Lighthing Effects
Select the desired lighting effect for your deck from a variety of built-in patterns. Check the Headlight box to turn on the front-facing LEDs on the LED-ring deck.


### 2. Intensity
Available only for the **LED tab** effect. Use this control to adjust the overall brightness of the LEDs.


### 3. Individual LEDs
Available only for the **LED tab** effect. Select a custom color for each of the 12 individual LEDs on the LED-ring deck.